==> flutterupushplugin-0.0.1.tar.gz: example/lib/test_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutterupushplugin/u_push_plugin.dart';
import 'package:flutterupushplugin/u_push_options.dart';
class TestPage extends StatefulWidget {
  @override
  _TestPage createState() => _TestPage();


}

class _TestPage extends State<TestPage> {

  int index=0;
  GlobalKey key;
  var  mapview1=null;
  UpushPlugin mUpushPlugin = UpushPlugin();
  String result = "返回消息提示";
  @override
  void dispose() {
    // TODO: implement dispose

    super.dispose();
  }
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    mUpushPlugin.addEventHandle(
        onReceiveCustomMessage: (Map<String, dynamic> event) {
          debugPrint(" 用户自定义消息内容： ${event} ");

          setState(() {
            result = " 正常推送消息内容： ${event} ";
          });
        }, onReceiveNotification: (Map<String, dynamic> event) {
      debugPrint(" 正常推送消息内容： ${event} ");

      _showMyDialog(" 正常推送消息内容： ${event} ");

      setState(() {
        result = event.toString();
      });
    }, onReceiveOffLineNotification: (Map<String, dynamic> event) {
      debugPrint(" 点击事件： ${event} ");
      setState(() {
        result = event.toString();
      });
    });

  }
   Future<void> _showMyDialog(String text) async {
     return showDialog<void>(
      context: context,
       barrierDismissible: false, // user must tap button!
       builder: (BuildContext context) {
         return AlertDialog(
           title: Text('AlertDialog Title ${text} '),
          content: SingleChildScrollView(
             child: ListBody(
               children: <Widget>[
                Text('This is a demo alert dialog.'),
                 Text('Would you like to approve of this message?'),
               ],
             ),
           ),
           actions: <Widget>[
             FlatButton(
               child: Text('Approve'),
               onPressed: () {
                 Navigator.of(context).pop();
               },
            ),
           ],
         );
       },
     );
   }
  @override
  Widget build(BuildContext context) {

    return Scaffold(

      appBar: AppBar(
        title: const Text('Plugin example app'),
      ),
      body:Center(
        child: Column(
          children: <Widget>[
            Text("返回结果：" + result),
            RaisedButton(
              onPressed: () {
                mUpushPlugin.addTags(["tags1", "tags2"]).then((value) {
                  debugPrint(" 添加标签 ${value} ");
                  setState(() {
                    result = " 添加标签 ${value} ";
                  });
                });
              },
              child: Text("添加标签   tags1, tags2"),
            ),
            RaisedButton(
              onPressed: () {
                mUpushPlugin.deleteTags(["tags1", "tags2"]).then((value) {
                  debugPrint(" 删除标签 ${value} ");
                  setState(() {
                    result = " 删除标签 ${value} ";
                  });
                });
              },
              child: Text("删除标签  tags1, tags2"),
            ),
            RaisedButton(
              onPressed: () {
                mUpushPlugin.getTags().then((value) {
                  debugPrint(" 获取标签 ${value} ");
                  setState(() {
                    result = " 获取标签 ${value} ";
                  });
                });
              },
              child: Text("获取标签"),
            ),
            RaisedButton(
              onPressed: () {
                mUpushPlugin.addAlias("beiming","android").then((value) {
                  debugPrint(" 添加别名 ${value} ");
                  setState(() {
                    result = " 添加别名 ${value} ";
                  });
                });
              },
              child: Text("添加别名 android"),
            ),
            RaisedButton(
              onPressed: () {
                mUpushPlugin.setAlias("beiming","ios").then((value) {
                  debugPrint(" 设置别名 ${value} ");
                  setState(() {
                    result = " 设置别名 ${value} ";
                  });
                });
              },
              child: Text("设置别名 ios"),
            ),
            RaisedButton(
              onPressed: () {
                mUpushPlugin.deleteAlias("beiming","ios").then((value) {
                  debugPrint(" 删除别名 ${value} ");
                  setState(() {
                    result = " 删除别名 ${value} ";
                  });
                });
              },
              child: Text("删除别名 ios "),
            ),
            RaisedButton(
              onPressed: () {
                mUpushPlugin.getRegistrationId().then((value) {
                  debugPrint(" 获取注册id ${value} ");
                  setState(() {
                    result = " 获取注册id ${value} ";
                  });
                });
              },
              child: Text("获取注册id "),
            ),
          ],
        ),
      )


      ,
    );
  }
}

==> flutterupushplugin-0.0.3.tar.gz: example/lib/test_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutterupushplugin/u_push_plugin.dart';
import 'package:flutterupushplugin/u_push_options.dart';
class TestPage extends StatefulWidget {
  @override
  _TestPage createState() => _TestPage();


}

class _TestPage extends State<TestPage> {

  int index=0;
  GlobalKey key;
  var  mapview1=null;
  UpushPlugin mUpushPlugin = UpushPlugin();
  String result = "返回消息提示";
  @override
  void dispose() {
    // TODO: implement dispose

    super.dispose();
  }
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    //消息的回调
    mUpushPlugin.addEventHandle(
        onReceiveCustomMessage: (Map<String, dynamic> event) {
          setState(() {
            result = "用户自定义消息内容： ${event} ";
          });
        },
        onReceiveNotification: (Map<String, dynamic> event) {


      setState(() {
        result ="在线接收通知"+ event.toString();
      });
    },
        onReceiveOffLineNotification: (Map<String, dynamic> event) {
      setState(() {
        result = "离线通知："+event.toString();
      });
    });

  }
  @override
  Widget build(BuildContext context) {

    return Scaffold(

      appBar: AppBar(
        title: const Text('Plugin example app'),
      ),
      body:Center(
        child: Column(
          children: <Widget>[
            Text("返回结果：" + result),
            RaisedButton(
              onPressed: () {
                mUpushPlugin.addTags(["tags1", "tags2"]).then((value) {
                  debugPrint(" 添加标签 ${value} ");
                  setState(() {
                    result = " 添加标签  结果：${value} ";
                  });
                });
              },
              child: Text("添加标签   tags1, tags2"),
            ),
            RaisedButton(
              onPressed: () {
                mUpushPlugin.deleteTags(["tags1", "tags2"]).then((value) {
                  debugPrint(" 删除标签 结果：${value} ");
                  setState(() {
                    result = " 删除标签 结果：${value} ";
                  });
                });
              },
              child: Text("删除标签  tags1, tags2"),
            ),
            RaisedButton(
              onPressed: () {
                mUpushPlugin.getTags().then((value) {
                  debugPrint(" 获取标签  结果：${value} ");
                  setState(() {
                    result = " 获取标签 结果：${value} ";
                  });
                });
              },
              child: Text("获取标签"),
            ),
            RaisedButton(
              onPressed: () {
                mUpushPlugin.addAlias("flutter","android").then((value) {
                  debugPrint(" 添加别名  结果：${value} ");
                  setState(() {
                    result = " 添加别名 结果：${value} ";
                  });
                });
              },
              child: Text("同时添加别名 flutter，android"),
            ),
            RaisedButton(
              onPressed: () {
                mUpushPlugin.setAlias("flutter","ios").then((value) {
                  debugPrint(" 设置别名  结果：${value} ");
                  setState(() {
                    result = " 设置别名  结果：${value} ";
                  });
                });
              },
              child: Text("同时设置别名 flutter,ios"),
            ),
            RaisedButton(
              onPressed: () {
                mUpushPlugin.deleteAlias("flutter","ios").then((value) {
                  debugPrint(" 删除别名 结果：${value} ");
                  setState(() {
                    result = " 删除别名 结果：${value} ";
                  });
                });
              },
              child: Text("同时删除别名 flutter，ios "),
            ),
            RaisedButton(
              onPressed: () {
                mUpushPlugin.getRegistrationId().then((value) {
                  debugPrint(" 获取注册id ${value} ");
                  setState(() {
                    result = " 获取注册id ${value} ";
                  });
                });
              },
              child: Text("获取注册id "),
            ),
          ],
        ),
      )


      ,
    );
  }
}
